/**
 * @file	cf_file.h
 * @author	myusgun <myusgun@gmail.com>
 * @version	0.1
 *
 * @example file.c
 */
#ifndef __CF_FILE_H__
#define __CF_FILE_H__

#include "cf_base.h"
#include <fcntl.h>

/** 파일 열기 옵션 플래그 */
typedef enum {
	CF_FILE_RO = O_RDONLY,	/**< 읽기 전용 */
	CF_FILE_WO = O_WRONLY,	/**< 쓰기 전용 */
	CF_FILE_WR = O_RDWR,	/**< 읽기/쓰기 */
	CF_FILE_CR = O_CREAT,	/**< 파일이 존재하지 않으면 생성 */
	CF_FILE_TR = O_TRUNC,	/**< 파일이 존재하면 비우기 */
	CF_FILE_AP = O_APPEND	/**< 파일이 존재하면 이어서 쓰기 */
} E_CF_FILE_FLAG, CF_FILE_FLAG;

#ifdef __cplusplus
extern "C" {
#endif

CF_EXPORT int
CF_File_Open			(const char			* path,
						 const CF_FILE_FLAG	flag);

CF_EXPORT int
CF_File_Create			(const char * path);

CF_EXPORT int
CF_File_Close			(const int fd);

CF_EXPORT int
CF_File_Read			(const int		fd,
						 void			* buf,
						 const size_t	len);

CF_EXPORT int
CF_File_Write			(const int		fd,
						 const void		* buf, 
						 const size_t	len);

CF_EXPORT int
CF_File_GetSize			(const int fd);

CF_EXPORT int
CF_File_MakeDirectory	(const char * path);

#ifdef __cplusplus
}
#endif

#endif // #ifndef __CF_FILE_H__
